pub struct Body {
pub block_content: Vec<BlockContent>,
pub sect_pr: Option<Box<SectionProperties>>,
pub extra_children: Vec<PositionedNode>,
}Fields
block_content: Vec<BlockContent>sect_pr: Option<Box<SectionProperties>>extra_children: Vec<PositionedNode>Unknown child elements captured for roundtrip fidelity.
Implementations
Sourceimpl Body
impl Body
Sourcepub fn add_paragraph(&mut self) -> &mut Paragraph
pub fn add_paragraph(&mut self) -> &mut Paragraph
Add an empty paragraph and return a mutable reference to it.
Sourcepub fn add_table(&mut self) -> &mut Table
pub fn add_table(&mut self) -> &mut Table
Add an empty table and return a mutable reference to it.
Sourcepub fn set_section_properties(&mut self, sect_pr: SectionProperties)
pub fn set_section_properties(&mut self, sect_pr: SectionProperties)
Set section properties on the body.
Sourceimpl Body
impl Body
Sourcepub fn add_form_field(&mut self, config: FormFieldConfig) -> &mut Self
pub fn add_form_field(&mut self, config: FormFieldConfig) -> &mut Self
Add a form field as a Structured Document Tag (<w:sdt>).
Produces a block-level SDT containing an appropriate SDT properties
element (<w:sdtPr>) and content paragraph with the default value.
ECMA-376 Part 1, Section 17.5.2.
Sourceimpl Body
impl Body
Sourcepub fn add_toc(&mut self, opts: TocOptions) -> &mut Self
pub fn add_toc(&mut self, opts: TocOptions) -> &mut Self
Insert a Table of Contents field at the current position.
This writes:
- An optional title paragraph styled “TOC Heading”.
- A
TOCfield spanning three paragraphs:fldChar begin,instrText,fldChar end. - A placeholder paragraph telling the user to update the field.
ECMA-376 Part 1, Section 17.16.5.58 (TOC).